@@ -1,10 +1,10 @@
-/* Eye Of Gnome - Jobs  
+/* Eye Of Gnome - Jobs
  *
  * Copyright (C) 2006 The Free Software Foundation
  *
  * Author: Lucas Rocha <lucasr@gnome.org>
  *
- * Based on evince code (shell/ev-jobs.c) by: 
+ * Based on evince code (shell/ev-jobs.c) by:
  * 	- Martin Kretzschmar <martink@gnome.org>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -43,6 +43,7 @@ G_DEFINE_TYPE (EogJobModel, eog_job_model, EOG_TYPE_JOB);
 G_DEFINE_TYPE (EogJobTransform, eog_job_transform, EOG_TYPE_JOB);
 G_DEFINE_TYPE (EogJobSave, eog_job_save, EOG_TYPE_JOB);
 G_DEFINE_TYPE (EogJobSaveAs, eog_job_save_as, EOG_TYPE_JOB_SAVE);
+G_DEFINE_TYPE (EogJobCopy, eog_job_copy, EOG_TYPE_JOB);
 
 enum
 {
@@ -56,7 +57,7 @@ static guint job_signals[SIGNAL_LAST_SIGNAL];
 static void eog_job_save_real_run (EogJobSave *job);
 static void eog_job_save_as_real_run (EogJobSave *job);
 
-static void eog_job_init (EogJob *job) 
+static void eog_job_init (EogJob *job)
 {
 	job->mutex = g_mutex_new();
 	job->progress = 0.0;
@@ -155,7 +156,7 @@ eog_job_thumbnail_dispose (GObject *object)
 		g_object_unref (job->image);
 		job->image = NULL;
 	}
-	
+
 	if (job->thumbnail) {
 		g_object_unref (job->thumbnail);
 		job->thumbnail = NULL;
@@ -193,9 +194,9 @@ eog_job_thumbnail_run (EogJobThumbnail *job)
 {
 	gchar *orig_width, *orig_height;
 	gint width, height;
-	
+
 	g_return_if_fail (EOG_IS_JOB_THUMBNAIL (job));
-	
+
 	if (EOG_JOB (job)->error) {
 	        g_error_free (EOG_JOB (job)->error);
 		EOG_JOB (job)->error = NULL;
@@ -229,7 +230,7 @@ eog_job_thumbnail_run (EogJobThumbnail *job)
 				   GINT_TO_POINTER (height));
 		g_free (orig_height);
 	}
-	
+
 	if (EOG_JOB (job)->error) {
 		g_warning ("%s", EOG_JOB (job)->error->message);
 	}
@@ -274,7 +275,7 @@ eog_job_load_new (EogImage *image)
 	if (image) {
 		job->image = g_object_ref (image);
 	}
-	
+
 	return EOG_JOB (job);
 }
 
@@ -292,7 +293,7 @@ eog_job_load_run (EogJobLoad *job)
 			EOG_IMAGE_DATA_ALL,
 			EOG_JOB (job),
 			&EOG_JOB (job)->error);
-	
+
 	EOG_JOB (job)->finished = TRUE;
 }
 
@@ -343,7 +344,7 @@ filter_files (GSList *files, GList **file_list, GList **error_list)
 		file = (GFile *) it->data;
 
 		if (file != NULL) {
-			file_info = g_file_query_info (file, 
+			file_info = g_file_query_info (file,
 						       G_FILE_ATTRIBUTE_STANDARD_TYPE,
 						       0, NULL, NULL);
 			if (file_info == NULL) {
@@ -360,7 +361,7 @@ filter_files (GSList *files, GList **file_list, GList **error_list)
 			*file_list = g_list_prepend (*file_list, g_object_ref (file));
 			break;
 		default:
-			*error_list = g_list_prepend (*error_list, 
+			*error_list = g_list_prepend (*error_list,
 						      g_file_get_uri (file));
 			break;
 		}
@@ -383,7 +384,7 @@ eog_job_model_run (EogJobModel *job)
 	filter_files (job->file_list, &filtered_list, &error_list);
 
 	job->store = EOG_LIST_STORE (eog_list_store_new ());
-	
+
 	eog_list_store_add_files (job->store, filtered_list);
 
 	g_list_foreach (filtered_list, (GFunc) g_object_unref, NULL);
@@ -465,19 +466,19 @@ eog_job_transform_run (EogJobTransform *job)
 
 	for (it = job->images; it != NULL; it = it->next) {
 		EogImage *image = EOG_IMAGE (it->data);
-		
+
 		if (job->trans == NULL) {
 			eog_image_undo (image);
 		} else {
 			eog_image_transform (image, job->trans, EOG_JOB (job));
 		}
-		
+
 		if (eog_image_is_modified (image) || job->trans == NULL) {
 			g_object_ref (image);
 			g_idle_add (eog_job_transform_image_modified, image);
 		}
 	}
-	
+
 	EOG_JOB (job)->finished = TRUE;
 }
 
@@ -537,7 +538,7 @@ eog_job_save_real_run (EogJobSave *job)
 	GList *it;
 
 	job->current_pos = 0;
-	
+
 	for (it = job->images; it != NULL; it = it->next, job->current_pos++) {
 		EogImage *image = EOG_IMAGE (it->data);
 		EogImageSaveInfo *save_info = NULL;
@@ -550,21 +551,21 @@ eog_job_save_real_run (EogJobSave *job)
 		eog_image_data_ref (image);
 
 		if (!eog_image_has_data (image, EOG_IMAGE_DATA_ALL)) {
-			eog_image_load (image, 
+			eog_image_load (image,
 					EOG_IMAGE_DATA_ALL,
-					NULL, 
+					NULL,
 					&EOG_JOB (job)->error);
 		}
 
-		handler_id = g_signal_connect (G_OBJECT (image), 
+		handler_id = g_signal_connect (G_OBJECT (image),
 					       "save-progress",
-				               G_CALLBACK (save_progress_handler), 
+				               G_CALLBACK (save_progress_handler),
 					       job);
 
 		save_info = eog_image_save_info_from_image (image);
 
-		success = eog_image_save_by_info (image, 
-						  save_info, 
+		success = eog_image_save_by_info (image,
+						  save_info,
 						  &EOG_JOB (job)->error);
 
 		if (save_info)
@@ -597,7 +598,7 @@ static void eog_job_save_as_dispose (GObject *object)
 		g_object_unref (job->converter);
 		job->converter = NULL;
 	}
-	
+
 	if (job->file != NULL) {
 		g_object_unref (job->file);
 		job->file = NULL;
@@ -638,7 +639,7 @@ eog_job_save_as_real_run (EogJobSave *job)
 	guint n_images;
 
 	g_assert (EOG_IS_JOB_SAVE_AS (job));
-	
+
 	n_images = g_list_length (job->images);
 
 	saveas_job = EOG_JOB_SAVE_AS (job);
@@ -651,23 +652,23 @@ eog_job_save_as_real_run (EogJobSave *job)
 		EogImage *image = EOG_IMAGE (it->data);
 		gboolean success = FALSE;
 		gulong handler_id = 0;
-		
+
 		job->current_image = image;
 
 		eog_image_data_ref (image);
 
 		if (!eog_image_has_data (image, EOG_IMAGE_DATA_ALL)) {
-			eog_image_load (image, 
+			eog_image_load (image,
 					EOG_IMAGE_DATA_ALL,
-					NULL, 
+					NULL,
 					&EOG_JOB (job)->error);
 		}
 
 		g_assert (EOG_JOB (job)->error == NULL);
 
-		handler_id = g_signal_connect (G_OBJECT (image), 
+		handler_id = g_signal_connect (G_OBJECT (image),
 					       "save-progress",
-				               G_CALLBACK (save_progress_handler), 
+				               G_CALLBACK (save_progress_handler),
 					       job);
 
 		src_info = eog_image_save_info_from_image (image);
@@ -689,9 +690,9 @@ eog_job_save_as_real_run (EogJobSave *job)
 			gboolean result;
 
 			result = eog_uri_converter_do (saveas_job->converter,
-						       image, 
+						       image,
 						       &dest_file,
-						       &format, 
+						       &format,
 						       NULL);
 
 			g_assert (result);
@@ -700,9 +701,9 @@ eog_job_save_as_real_run (EogJobSave *job)
 								   format);
 		}
 
-		success = eog_image_save_as_by_info (image, 
-						     src_info, 
-						     dest_info, 
+		success = eog_image_save_as_by_info (image,
+						     src_info,
+						     dest_info,
 						     &EOG_JOB (job)->error);
 
 		if (src_info)
@@ -715,10 +716,92 @@ eog_job_save_as_real_run (EogJobSave *job)
 			g_signal_handler_disconnect (G_OBJECT (image), handler_id);
 
 		eog_image_data_unref (image);
-		
+
 		if (!success)
 			break;
 	}
 
 	EOG_JOB (job)->finished = TRUE;
 }
+
+static void eog_job_copy_init (EogJobCopy *job) { /* do nothing */};
+
+static void
+eog_job_copy_dispose (GObject *object)
+{
+	EogJobCopy *job = EOG_JOB_COPY (object);
+
+	if (job->dest) {
+		g_free (job->dest);
+		job->dest = NULL;
+	}
+
+	(* G_OBJECT_CLASS (eog_job_copy_parent_class)->dispose) (object);
+}
+
+static void
+eog_job_copy_class_init (EogJobCopyClass *class)
+{
+	G_OBJECT_CLASS (class)->dispose = eog_job_copy_dispose;
+}
+
+EogJob *
+eog_job_copy_new (GList *images, const gchar *dest)
+{
+	EogJobCopy *job;
+
+	g_assert (images != NULL && dest != NULL);
+
+	job = g_object_new (EOG_TYPE_JOB_COPY, NULL);
+
+	job->images = images;
+	job->dest = g_strdup (dest);
+
+	return EOG_JOB (job);
+}
+
+static void
+eog_job_copy_progress_callback (goffset current_num_bytes,
+				goffset total_num_bytes,
+				gpointer user_data)
+{
+	gfloat job_progress;
+	guint n_images;
+	EogJobCopy *job;
+
+	job = EOG_JOB_COPY (user_data);
+	n_images = g_list_length (job->images);
+
+	job_progress =  ((current_num_bytes / (gfloat) total_num_bytes) + job->current_pos)/n_images;
+
+	eog_job_set_progress (EOG_JOB (job), job_progress);
+}
+
+void
+eog_job_copy_run (EogJobCopy *job)
+{
+	GList *it;
+	guint n_images;
+	GFile *src, *dest;
+	gchar *filename, *dest_filename;
+
+	n_images = g_list_length (job->images);
+
+	job->current_pos = 0;
+
+	for (it = job->images; it != NULL; it = g_list_next (it), job->current_pos++) {
+		src = (GFile *) it->data;
+		filename = g_file_get_basename (src);
+		dest_filename = g_build_filename (job->dest, filename, NULL);
+		dest = g_file_new_for_path (dest_filename);
+
+		g_file_copy (src, dest,
+			     G_FILE_COPY_OVERWRITE, NULL,
+			     eog_job_copy_progress_callback, job,
+			     &EOG_JOB (job)->error);
+		g_free (filename);
+		g_free (dest_filename);
+	}
+
+	EOG_JOB (job)->finished = TRUE;
+}
