@@ -1,10 +1,10 @@
-/* Eye Of Gnome - Thumbnailing functions 
+/* Eye Of Gnome - Thumbnailing functions
  *
  * Copyright (C) 2000-2008 The Free Software Foundation
  *
  * Author: Lucas Rocha <lucasr@gnome.org>
  *
- * Based on eel code (eel/eel-graphic-effects.c) by: 
+ * Based on eel code (eel/eel-graphic-effects.c) by:
  * 	- Andy Hertzfeld <andy@eazel.com>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -60,24 +60,24 @@ eog_thumb_error_quark (void)
 	static GQuark q = 0;
 	if (q == 0)
 		q = g_quark_from_static_string ("eog-thumb-error-quark");
-	
+
 	return q;
 }
 
 static void
 set_vfs_error (GError **error, GError *ioerror)
 {
-	g_set_error (error, 
-		     EOG_THUMB_ERROR, 
+	g_set_error (error,
+		     EOG_THUMB_ERROR,
 		     EOG_THUMB_ERROR_VFS,
 		     "%s", ioerror ? ioerror->message : "VFS error making a thumbnail");
 }
 
 static void
-set_thumb_error (GError **error, int error_id, const char *string) 
+set_thumb_error (GError **error, int error_id, const char *string)
 {
-	g_set_error (error, 
-		     EOG_THUMB_ERROR, 
+	g_set_error (error,
+		     EOG_THUMB_ERROR,
 		     error_id,
 		     "%s", string);
 }
@@ -92,7 +92,7 @@ get_valid_thumbnail (EogThumbData *data, GError **error)
 	/* does a thumbnail under the path exists? */
 	if (data->thumb_exists) {
 		thumb = gdk_pixbuf_new_from_file (data->thumb_path, error);
-		
+
 		/* is this thumbnail file up to date? */
 		if (thumb != NULL && !gnome_thumbnail_is_valid (thumb, data->uri_str, data->mtime)) {
 			g_object_unref (thumb);
@@ -116,12 +116,12 @@ create_thumbnail_from_pixbuf (EogThumbData *data,
 
 	width = gdk_pixbuf_get_width (pixbuf);
 	height = gdk_pixbuf_get_height (pixbuf);
-	
+
 	perc = CLAMP (128.0/(MAX (width, height)), 0, 1);
 
 	thumb = gnome_thumbnail_scale_down_pixbuf (pixbuf,
 						   width*perc, height*perc);
-	
+
 	return thumb;
 }
 
@@ -143,13 +143,13 @@ eog_thumb_data_new (GFile *file, GError **error)
 {
 	EogThumbData *data;
 	GFileInfo *file_info;
-	GError *ioerror;
+	GError *ioerror = NULL;
 
 	g_return_val_if_fail (file != NULL, NULL);
 	g_return_val_if_fail (error != NULL && *error == NULL, NULL);
-	
+
 	data = g_slice_new0 (EogThumbData);
-	
+
 	data->uri_str    = g_file_get_uri (file);
 	data->thumb_path = gnome_thumbnail_path_for_uri (data->uri_str, GNOME_THUMBNAIL_SIZE_NORMAL);
 
@@ -163,7 +163,7 @@ eog_thumb_data_new (GFile *file, GError **error)
 	if (file_info == NULL)
 	{
 		set_vfs_error (error, ioerror);
-		g_error_free (ioerror);
+		g_clear_error (&ioerror);
 	}
 
 	if (*error == NULL) {
@@ -171,21 +171,21 @@ eog_thumb_data_new (GFile *file, GError **error)
 		data->mtime = g_file_info_get_attribute_uint64 (file_info,
 								G_FILE_ATTRIBUTE_TIME_MODIFIED);
 		data->mime_type = g_strdup (g_file_info_get_content_type (file_info));
-		
-		data->thumb_exists = (g_file_info_get_attribute_byte_string (file_info, 
+
+		data->thumb_exists = (g_file_info_get_attribute_byte_string (file_info,
 					                                     G_FILE_ATTRIBUTE_THUMBNAIL_PATH) != NULL);
 		data->failed_thumb_exists = g_file_info_get_attribute_boolean (file_info,
 									       G_FILE_ATTRIBUTE_THUMBNAILING_FAILED);
 		data->can_read = TRUE;
 		if (g_file_info_has_attribute (file_info, G_FILE_ATTRIBUTE_ACCESS_CAN_READ)) {
-			data->can_read = g_file_info_get_attribute_boolean (file_info, 
+			data->can_read = g_file_info_get_attribute_boolean (file_info,
 									    G_FILE_ATTRIBUTE_ACCESS_CAN_READ);
 		}
 	}
 	else {
 		eog_thumb_data_free (data);
 		data = NULL;
-		g_error_free (ioerror);
+		g_clear_error (&ioerror);
 	}
 
 	g_object_unref (file_info);
@@ -194,79 +194,79 @@ eog_thumb_data_new (GFile *file, GError **error)
 }
 
 static void
-draw_frame_row (GdkPixbuf *frame_image, 
-		gint target_width, 
-		gint source_width, 
-		gint source_v_position, 
-		gint dest_v_position, 
-		GdkPixbuf *result_pixbuf, 
-		gint left_offset, 
+draw_frame_row (GdkPixbuf *frame_image,
+		gint target_width,
+		gint source_width,
+		gint source_v_position,
+		gint dest_v_position,
+		GdkPixbuf *result_pixbuf,
+		gint left_offset,
 		gint height)
 {
 	gint remaining_width, h_offset, slab_width;
-	
+
 	remaining_width = target_width;
 	h_offset = 0;
 
-	while (remaining_width > 0) {	
-		slab_width = remaining_width > source_width ? 
+	while (remaining_width > 0) {
+		slab_width = remaining_width > source_width ?
 			     source_width : remaining_width;
 
-		gdk_pixbuf_copy_area (frame_image, 
-				      left_offset, 
-				      source_v_position, 
-				      slab_width, 
-				      height, 
-				      result_pixbuf, 
-				      left_offset + h_offset, 
+		gdk_pixbuf_copy_area (frame_image,
+				      left_offset,
+				      source_v_position,
+				      slab_width,
+				      height,
+				      result_pixbuf,
+				      left_offset + h_offset,
 				      dest_v_position);
 
 		remaining_width -= slab_width;
-		h_offset += slab_width; 
+		h_offset += slab_width;
 	}
 }
 
 static void
-draw_frame_column (GdkPixbuf *frame_image, 
-		   gint target_height, 
-		   gint source_height, 
-		   gint source_h_position, 
-		   gint dest_h_position, 
-		   GdkPixbuf *result_pixbuf, 
-		   gint top_offset, 
+draw_frame_column (GdkPixbuf *frame_image,
+		   gint target_height,
+		   gint source_height,
+		   gint source_h_position,
+		   gint dest_h_position,
+		   GdkPixbuf *result_pixbuf,
+		   gint top_offset,
 		   gint width)
 {
 	gint remaining_height, v_offset, slab_height;
-	
+
 	remaining_height = target_height;
 	v_offset = 0;
 
-	while (remaining_height > 0) {	
-		slab_height = remaining_height > source_height ? 
+	while (remaining_height > 0) {
+		slab_height = remaining_height > source_height ?
 			      source_height : remaining_height;
 
-		gdk_pixbuf_copy_area (frame_image, 
-				      source_h_position, 
-				      top_offset, 
-				      width, 
-				      slab_height, 
-				      result_pixbuf, 
-				      dest_h_position, 
+		gdk_pixbuf_copy_area (frame_image,
+				      source_h_position,
+				      top_offset,
+				      width,
+				      slab_height,
+				      result_pixbuf,
+				      dest_h_position,
 				      top_offset + v_offset);
 
 		remaining_height -= slab_height;
-		v_offset += slab_height; 
+		v_offset += slab_height;
 	}
 }
 
 static GdkPixbuf *
-eog_thumbnail_stretch_frame_image (GdkPixbuf *frame_image, 
-				   gint left_offset, 
-				   gint top_offset, 
-				   gint right_offset, 
+eog_thumbnail_stretch_frame_image (GdkPixbuf *frame_image,
+				   gint left_offset,
+				   gint top_offset,
+				   gint right_offset,
 				   gint bottom_offset,
-                                   gint dest_width, 
-				   gint dest_height, 
+                                   gint dest_width,
+				   gint dest_height,
 				   gboolean fill_flag)
 {
         GdkPixbuf *result_pixbuf;
@@ -280,15 +280,15 @@ eog_thumbnail_stretch_frame_image (GdkPixbuf *frame_image,
         frame_height = gdk_pixbuf_get_height (frame_image );
 
         if (fill_flag) {
-		result_pixbuf = gdk_pixbuf_scale_simple (frame_image, 
-							 dest_width, 
-							 dest_height, 
+		result_pixbuf = gdk_pixbuf_scale_simple (frame_image,
+							 dest_width,
+							 dest_height,
 							 GDK_INTERP_NEAREST);
         } else {
-                result_pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, 
-						TRUE, 
-						8, 
-						dest_width, 
+                result_pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB,
+						TRUE,
+						8,
+						dest_width,
 						dest_height);
         }
 
@@ -297,9 +297,9 @@ eog_thumbnail_stretch_frame_image (GdkPixbuf *frame_image,
 
         if (!fill_flag) {
         	for (y = 0; y < dest_height; y++) {
-			art_rgb_run_alpha (pixels_ptr, 
-					   255, 255, 
-					   255, 255, 
+			art_rgb_run_alpha (pixels_ptr,
+					   255, 255,
+					   255, 255,
 					   dest_width);
 			pixels_ptr += row_stride;
         	}
@@ -312,79 +312,79 @@ eog_thumbnail_stretch_frame_image (GdkPixbuf *frame_image,
         target_frame_height = frame_height - top_offset - bottom_offset;
 
         /* Draw the left top corner  and top row */
-        gdk_pixbuf_copy_area (frame_image, 
-			      0, 0, 
-			      left_offset, 
-			      top_offset, 
-			      result_pixbuf, 
+        gdk_pixbuf_copy_area (frame_image,
+			      0, 0,
+			      left_offset,
+			      top_offset,
+			      result_pixbuf,
 			      0, 0);
 
-        draw_frame_row (frame_image, 
-			target_width, 
-			target_frame_width, 
-			0, 0, 
-			result_pixbuf, 
-			left_offset, 
+        draw_frame_row (frame_image,
+			target_width,
+			target_frame_width,
+			0, 0,
+			result_pixbuf,
+			left_offset,
 			top_offset);
 
         /* Draw the right top corner and left column */
-        gdk_pixbuf_copy_area (frame_image, 
-			      frame_width - right_offset, 
-			      0, 
-			      right_offset, 
-			      top_offset, 
-			      result_pixbuf, 
-			      dest_width - right_offset,  
+        gdk_pixbuf_copy_area (frame_image,
+			      frame_width - right_offset,
+			      0,
+			      right_offset,
+			      top_offset,
+			      result_pixbuf,
+			      dest_width - right_offset,
 			      0);
 
-        draw_frame_column (frame_image, 
-			   target_height, 
-			   target_frame_height, 
-			   0, 0, 
-			   result_pixbuf, 
-			   top_offset, 
+        draw_frame_column (frame_image,
+			   target_height,
+			   target_frame_height,
+			   0, 0,
+			   result_pixbuf,
+			   top_offset,
 			   left_offset);
 
         /* Draw the bottom right corner and bottom row */
-        gdk_pixbuf_copy_area (frame_image, 
-			      frame_width - right_offset, 
-			      frame_height - bottom_offset, 
-			      right_offset, 
-			      bottom_offset, 
-			      result_pixbuf, 
-			      dest_width - right_offset,  
+        gdk_pixbuf_copy_area (frame_image,
+			      frame_width - right_offset,
+			      frame_height - bottom_offset,
+			      right_offset,
+			      bottom_offset,
+			      result_pixbuf,
+			      dest_width - right_offset,
 			      dest_height - bottom_offset);
 
-        draw_frame_row (frame_image, 
-			target_width, 
-			target_frame_width, 
-			frame_height - bottom_offset, 
-			dest_height - bottom_offset, 
-			result_pixbuf, 
+        draw_frame_row (frame_image,
+			target_width,
+			target_frame_width,
+			frame_height - bottom_offset,
+			dest_height - bottom_offset,
+			result_pixbuf,
 			left_offset, bottom_offset);
 
         /* Draw the bottom left corner and the right column */
-        gdk_pixbuf_copy_area (frame_image, 
-			      0, 
-			      frame_height - bottom_offset, 
-			      left_offset, 
-			      bottom_offset, 
-			      result_pixbuf, 
+        gdk_pixbuf_copy_area (frame_image,
+			      0,
+			      frame_height - bottom_offset,
+			      left_offset,
+			      bottom_offset,
+			      result_pixbuf,
 			      0,
 			      dest_height - bottom_offset);
 
-        draw_frame_column (frame_image, 
-			   target_height, 
-			   target_frame_height, 
-			   frame_width - right_offset, 
-			   dest_width - right_offset, 
-			   result_pixbuf, top_offset, 
+        draw_frame_column (frame_image,
+			   target_height,
+			   target_frame_height,
+			   frame_width - right_offset,
+			   dest_width - right_offset,
+			   result_pixbuf, top_offset,
 			   right_offset);
 
         return result_pixbuf;
 }
 
-void 
+void
 eog_thumbnail_add_frame (GdkPixbuf **thumbnail)
 {
 	GdkPixbuf *result_pixbuf;
@@ -393,21 +393,21 @@ eog_thumbnail_add_frame (GdkPixbuf **thumbnail)
 
 	source_width  = gdk_pixbuf_get_width  (*thumbnail);
 	source_height = gdk_pixbuf_get_height (*thumbnail);
-	
+
 	dest_width  = source_width  + 9;
 	dest_height = source_height + 9;
 
-	result_pixbuf = eog_thumbnail_stretch_frame_image (frame, 
+	result_pixbuf = eog_thumbnail_stretch_frame_image (frame,
 							   3, 3, 6, 6,
-	                                	           dest_width, 
+	                                	           dest_width,
 							   dest_height,
 							   FALSE);
 
-	gdk_pixbuf_copy_area (*thumbnail, 
-			      0, 0, 
-			      source_width, 
-			      source_height, 
-			      result_pixbuf, 
+	gdk_pixbuf_copy_area (*thumbnail,
+			      0, 0,
+			      source_width,
+			      source_height,
+			      result_pixbuf,
 			      3, 3);
 
 	g_object_unref (*thumbnail);
@@ -430,15 +430,15 @@ eog_thumbnail_fit_to_size (GdkPixbuf **thumbnail, gint dimension)
 		if (width > height) {
 			factor = (gfloat) dimension / (gfloat) width;
 		} else {
-			factor = (gfloat) dimension / (gfloat) height;			
+			factor = (gfloat) dimension / (gfloat) height;
 		}
-		
+
 		width  = MAX (width  * factor, 1);
 		height = MAX (height * factor, 1);
-		
-		result_pixbuf = gnome_thumbnail_scale_down_pixbuf (*thumbnail, 
+
+		result_pixbuf = gnome_thumbnail_scale_down_pixbuf (*thumbnail,
 							           width, height);
-		
+
 		g_object_unref (*thumbnail);
 
 		*thumbnail = result_pixbuf;
@@ -459,7 +459,7 @@ eog_thumbnail_load (EogImage *image, GError **error)
 	file = eog_image_get_file (image);
 	data = eog_thumb_data_new (file, error);
 	g_object_unref (file);
-	
+
 	if (data == NULL)
 		return NULL;
 
