@@ -28,13 +28,13 @@ typedef struct {
 
 
 struct _EogURIConverterPrivate {
-	GnomeVFSURI     *base_uri;
+	GFile           *base_file;
 	GList           *token_list;
 	char            *suffix;
 	GdkPixbufFormat *img_format;
 	char            *counter_str;
 	gboolean        requires_exif;
-	
+
 	/* options */
 	gboolean convert_spaces;
 	gchar    space_character;
@@ -66,7 +66,7 @@ free_token (gpointer data)
 		g_free (token->data.string);
 	}
 
-	g_free (token);
+	g_slice_free (EogUCToken, token);
 }
 
 static void
@@ -77,9 +77,9 @@ eog_uri_converter_dispose (GObject *object)
 
 	priv = instance->priv;
 
-	if (priv->base_uri) {
-		gnome_vfs_uri_unref (priv->base_uri);
-		priv->base_uri = NULL;
+	if (priv->base_file) {
+		g_object_unref (priv->base_file);
+		priv->base_file = NULL;
 	}
 
 	if (priv->token_list) {
@@ -116,7 +116,7 @@ eog_uri_converter_init (EogURIConverter *obj)
 	priv->requires_exif     = FALSE;
 }
 
-static void 
+static void
 eog_uri_converter_class_init (EogURIConverterClass *klass)
 {
 	GObjectClass *object_class = (GObjectClass*) klass;
@@ -139,7 +139,7 @@ eog_uri_converter_class_init (EogURIConverterClass *klass)
                 PROP_SPACE_CHARACTER,
                 g_param_spec_char ("space-character", NULL, NULL,
 				   ' ', '~', '_', G_PARAM_READWRITE));
-	
+
        g_object_class_install_property (
                 object_class,
                 PROP_COUNTER_START,
@@ -177,17 +177,17 @@ eog_uc_error_quark (void)
 	static GQuark q = 0;
 	if (q == 0)
 		q = g_quark_from_static_string ("eog-uri-converter-error-quark");
-	
+
 	return q;
 }
 
-static void 
+static void
 update_counter_format_str (EogURIConverter *conv)
 {
 	EogURIConverterPrivate *priv;
 
 	g_return_if_fail (EOG_IS_URI_CONVERTER (conv));
-	
+
 	priv = conv->priv;
 
 	g_free (priv->counter_str);
@@ -220,14 +220,14 @@ eog_uri_converter_set_property (GObject      *object,
 		priv->space_character = g_value_get_char (value);
 		break;
 
-	case PROP_COUNTER_START: 
+	case PROP_COUNTER_START:
 	{
 		guint new_n_digits;
 
 		priv->counter_start = g_value_get_ulong (value);
-		
+
 		new_n_digits = ceil (log10 (priv->counter_start + pow (10, priv->counter_n_digits) - 1));
-		
+
 		if (new_n_digits != priv->counter_n_digits) {
 			priv->counter_n_digits = ceil (MIN (log10 (G_MAXULONG), new_n_digits));
 			update_counter_format_str (conv);
@@ -241,7 +241,7 @@ eog_uri_converter_set_property (GObject      *object,
 		break;
 
 	case PROP_N_IMAGES:
-		priv->counter_n_digits = ceil (MIN (log10 (G_MAXULONG), 
+		priv->counter_n_digits = ceil (MIN (log10 (G_MAXULONG),
 						    log10 (priv->counter_start + g_value_get_uint (value))));
 		update_counter_format_str (conv);
 		break;
@@ -295,7 +295,7 @@ enum {
 };
 
 static EogUCToken*
-create_token_string (const char *string, int substr_start, int substr_len) 
+create_token_string (const char *string, int substr_start, int substr_len)
 {
 	char *start_byte;
 	char *end_byte;
@@ -311,11 +311,11 @@ create_token_string (const char *string, int substr_start, int substr_len)
 	/* FIXME: is this right? */
 	n_bytes = end_byte - start_byte;
 
-	token = g_new0 (EogUCToken, 1);
+	token = g_slice_new0 (EogUCToken);
 	token->type = EOG_UC_STRING;
 	token->data.string = g_new0 (char, n_bytes);
 	token->data.string = g_utf8_strncpy (token->data.string, start_byte, substr_len);
-	
+
 	return token;
 }
 
@@ -324,7 +324,7 @@ create_token_counter (int start_counter)
 {
 	EogUCToken *token;
 
-	token = g_new0 (EogUCToken, 1);
+	token = g_slice_new0 (EogUCToken);
 	token->type = EOG_UC_COUNTER;
 	token->data.counter = 0;
 
@@ -336,7 +336,7 @@ create_token_other (EogUCType type)
 {
 	EogUCToken *token;
 
-	token = g_new0 (EogUCToken, 1);
+	token = g_slice_new0 (EogUCToken);
 	token->type = type;
 
 	return token;
@@ -354,12 +354,12 @@ eog_uri_converter_parse_string (EogURIConverter *conv, const char *string)
 	int substr_len = 0;
 	gunichar c;
 	const char *s;
-	EogUCToken *token; 
+	EogUCToken *token;
 
 	g_return_val_if_fail (EOG_IS_URI_CONVERTER (conv), NULL);
 
 	priv = conv->priv;
-	
+
 	if (string == NULL) return NULL;
 
 	if (!g_utf8_validate (string, -1, NULL))
@@ -371,7 +371,7 @@ eog_uri_converter_parse_string (EogURIConverter *conv, const char *string)
 	for (i = 0; i < len; i++) {
 		c = g_utf8_get_char (s);
 		token = NULL;
-		
+
 		switch (state) {
 		case PARSER_NONE:
 			if (c == '%') {
@@ -399,7 +399,7 @@ eog_uri_converter_parse_string (EogURIConverter *conv, const char *string)
 
 		case PARSER_TOKEN: {
 			EogUCType type = EOG_UC_END;
-			
+
 			if (c == 'f') {
 				type = EOG_UC_FILENAME;
 			}
@@ -434,9 +434,9 @@ eog_uri_converter_parse_string (EogURIConverter *conv, const char *string)
 			else if (c == 's') {
 				type = EOG_UC_SECOND;
 			}
-			
+
 			if (type != EOG_UC_END && token == NULL) {
-				token = create_token_other (type); 
+				token = create_token_other (type);
 				priv->requires_exif = TRUE;
 			}
 			state = PARSER_NONE;
@@ -450,7 +450,7 @@ eog_uri_converter_parse_string (EogURIConverter *conv, const char *string)
 		if (token != NULL) {
 			list = g_list_append (list, token);
 		}
-		
+
 		s = g_utf8_next_char (s);
 	}
 
@@ -462,7 +462,7 @@ eog_uri_converter_parse_string (EogURIConverter *conv, const char *string)
 	return list;
 }
 
-void 
+void
 eog_uri_converter_print_list (EogURIConverter *conv)
 {
 	EogURIConverterPrivate *priv;
@@ -477,7 +477,7 @@ eog_uri_converter_print_list (EogURIConverter *conv)
 		char *str;
 
 		token = (EogUCToken*) it->data;
-		
+
 		switch (token->type) {
 		case EOG_UC_STRING:
 			str = g_strdup_printf ("string [%s]", token->data.string);
@@ -519,7 +519,7 @@ eog_uri_converter_print_list (EogURIConverter *conv)
 			str = "unknown";
 			break;
 		}
-		
+
 		g_print ("- %s\n", str);
 
 		if (token->type == EOG_UC_STRING || token->type == EOG_UC_COUNTER) {
@@ -530,19 +530,19 @@ eog_uri_converter_print_list (EogURIConverter *conv)
 
 
 EogURIConverter*
-eog_uri_converter_new (GnomeVFSURI *base_uri, GdkPixbufFormat *img_format, const char *format_str)
+eog_uri_converter_new (GFile *base_file, GdkPixbufFormat *img_format, const char *format_str)
 {
 	EogURIConverter *conv;
 
 	g_return_val_if_fail (format_str != NULL, NULL);
 
 	conv = g_object_new (EOG_TYPE_URI_CONVERTER, NULL);
-	
-	if (base_uri != NULL) {
-		conv->priv->base_uri  = gnome_vfs_uri_ref (base_uri);
+
+	if (base_file != NULL) {
+		conv->priv->base_file  = g_object_ref (base_file);
 	}
 	else {
-		conv->priv->base_uri = NULL;
+		conv->priv->base_file = NULL;
 	}
 	conv->priv->img_format = img_format;
 	conv->priv->token_list = eog_uri_converter_parse_string (conv, format_str);
@@ -550,85 +550,83 @@ eog_uri_converter_new (GnomeVFSURI *base_uri, GdkPixbufFormat *img_format, const
 	return conv;
 }
 
-static GnomeVFSURI*
-get_uri_directory (EogURIConverter *conv, EogImage *image)
+static GFile*
+get_file_directory (EogURIConverter *conv, EogImage *image)
 {
-	GnomeVFSURI *uri = NULL;
+	GFile *file = NULL;
 	EogURIConverterPrivate *priv;
 
 	g_return_val_if_fail (EOG_IS_URI_CONVERTER (conv), NULL);
 	g_return_val_if_fail (EOG_IS_IMAGE (image), NULL);
-	
+
 	priv = conv->priv;
 
-	if (priv->base_uri != NULL) {
-		uri = gnome_vfs_uri_ref (priv->base_uri);
+	if (priv->base_file != NULL) {
+		file = g_object_ref (priv->base_file);
 	}
 	else {
-		GnomeVFSURI *img_uri;
+		GFile *img_file;
 
-		img_uri = eog_image_get_uri (image);
-		g_assert (img_uri != NULL);
+		img_file = eog_image_get_file (image);
+		g_assert (img_file != NULL);
 
- 		if (gnome_vfs_uri_has_parent (img_uri)) {
-			uri = gnome_vfs_uri_get_parent (img_uri);
-		}
+		file = g_file_get_parent (img_file);
 
-		gnome_vfs_uri_unref (img_uri);
+		g_object_unref (img_file);
 	}
 
-	return uri;
+	return file;
 }
 
 static void
-split_filename (GnomeVFSURI *uri, char **name, char **suffix)
+split_filename (GFile *file, char **name, char **suffix)
 {
-	char *short_name;
+	char *basename;
 	char *suffix_start;
 	guint len;
-		
+
 	*name = NULL;
 	*suffix = NULL;
 
         /* get unescaped string */
-	short_name = gnome_vfs_uri_extract_short_name (uri); 
+	basename = g_file_get_basename (file);
 
 	/* FIXME: does this work for all locales? */
-	suffix_start = g_utf8_strrchr (short_name, -1, '.'); 
-	
+	suffix_start = g_utf8_strrchr (basename, -1, '.');
+
 	if (suffix_start == NULL) { /* no suffix found */
-		*name = g_strdup (short_name);
+		*name = g_strdup (basename);
 	}
 	else {
-		len = (suffix_start - short_name);
-		*name = g_strndup (short_name, len);
+		len = (suffix_start - basename);
+		*name = g_strndup (basename, len);
 
-		len = strlen (short_name) - len - 1;
+		len = strlen (basename) - len - 1;
 		*suffix = g_strndup (suffix_start+1, len);
 	}
 
-	g_free (short_name);
+	g_free (basename);
 }
 
 static GString*
 append_filename (GString *str, EogImage *img)
 {
-	/* appends the name of the original file without 
+	/* appends the name of the original file without
 	   filetype suffix */
-	GnomeVFSURI *img_uri;
+	GFile *img_file;
 	char *name;
 	char *suffix;
 	GString *result;
-	
-	img_uri = eog_image_get_uri (img);
-	split_filename (img_uri, &name, &suffix);
+
+	img_file = eog_image_get_file (img);
+	split_filename (img_file, &name, &suffix);
 
 	result = g_string_append (str, name);
 
 	g_free (name);
 	g_free (suffix);
-	
-	gnome_vfs_uri_unref (img_uri);
+
+	g_object_unref (img_file);
 
 	return result;
 }
@@ -651,58 +649,58 @@ append_counter (GString *str, gulong counter,  EogURIConverter *conv)
 
 
 static void
-build_absolute_uri (EogURIConverter *conv, EogImage *image, GString *str,  /* input */
-		    GnomeVFSURI **uri, GdkPixbufFormat **format)           /* output */
-{ 
-	GnomeVFSURI *dir_uri;
+build_absolute_file (EogURIConverter *conv, EogImage *image, GString *str,  /* input  */
+		     GFile **file, GdkPixbufFormat **format)                /* output */
+{
+	GFile *dir_file;
 	EogURIConverterPrivate *priv;
-	
-	*uri = NULL;
+
+	*file = NULL;
 	if (format != NULL)
 		*format = NULL;
 
 	g_return_if_fail (EOG_IS_URI_CONVERTER (conv));
 	g_return_if_fail (EOG_IS_IMAGE (image));
-	g_return_if_fail (uri != NULL);
+	g_return_if_fail (file != NULL);
 	g_return_if_fail (str != NULL);
 
 	priv = conv->priv;
 
-	dir_uri = get_uri_directory (conv, image);
-	g_assert (dir_uri != NULL);
-	
+	dir_file = get_file_directory (conv, image);
+	g_assert (dir_file != NULL);
+
 	if (priv->img_format == NULL) {
 		/* use same file type/suffix */
 		char *name;
 		char *old_suffix;
-		GnomeVFSURI *img_uri;
+		GFile *img_file;
 
-		img_uri = eog_image_get_uri (image);
-		split_filename (img_uri, &name, &old_suffix);
+		img_file = eog_image_get_file (image);
+		split_filename (img_file, &name, &old_suffix);
 
 		g_assert (old_suffix != NULL);
 
 		g_string_append_unichar (str, '.');
 		g_string_append (str, old_suffix);
 
-		if (format != NULL) 
+		if (format != NULL)
 			*format = eog_pixbuf_get_format_by_suffix (old_suffix);
 
-		gnome_vfs_uri_unref (img_uri);
+		g_object_unref (img_file);
 	} else {
-		if (priv->suffix == NULL) 
+		if (priv->suffix == NULL)
 			priv->suffix = eog_pixbuf_get_common_suffix (priv->img_format);
 
 		g_string_append_unichar (str, '.');
 		g_string_append (str, priv->suffix);
 
-		if (format != NULL) 
+		if (format != NULL)
 			*format = priv->img_format;
 	}
-	
-	*uri = gnome_vfs_uri_append_file_name (dir_uri, str->str);
-	
-	gnome_vfs_uri_unref (dir_uri);
+
+	*file = g_file_get_child (dir_file, str->str);
+
+	g_object_unref (dir_file);
 }
 
 
@@ -753,7 +751,7 @@ replace_remove_chars (GString *str, gboolean convert_spaces, gunichar space_char
  */
 gboolean
 eog_uri_converter_do (EogURIConverter *conv, EogImage *image,
-		      GnomeVFSURI **uri, GdkPixbufFormat **format, GError **error)
+		      GFile **file, GdkPixbufFormat **format, GError **error)
 {
 	EogURIConverterPrivate *priv;
 	GList *it;
@@ -764,8 +762,8 @@ eog_uri_converter_do (EogURIConverter *conv, EogImage *image,
 
 	priv = conv->priv;
 
-	*uri = NULL;
-	if (format != NULL) 
+	*file = NULL;
+	if (format != NULL)
 		*format = NULL;
 
 	str = g_string_new ("");
@@ -783,9 +781,9 @@ eog_uri_converter_do (EogURIConverter *conv, EogImage *image,
 			break;
 
 		case EOG_UC_COUNTER: {
-			if (token->data.counter < priv->counter_start) 
+			if (token->data.counter < priv->counter_start)
 				token->data.counter = priv->counter_start;
-			
+
 			str = append_counter (str, token->data.counter++, conv);
 			break;
 		}
@@ -821,7 +819,7 @@ eog_uri_converter_do (EogURIConverter *conv, EogImage *image,
 #endif
 		default:
 		/* skip all others */
-		
+
 			break;
 		}
 	}
@@ -829,19 +827,19 @@ eog_uri_converter_do (EogURIConverter *conv, EogImage *image,
 	repl_str = replace_remove_chars (str, priv->convert_spaces, priv->space_character);
 
 	if (repl_str->len > 0) {
-		build_absolute_uri (conv, image, repl_str, uri, format);
+		build_absolute_file (conv, image, repl_str, file, format);
 	}
 
 	g_string_free (repl_str, TRUE);
 	g_string_free (str, TRUE);
-	
 
-	return (*uri != NULL);
+
+	return (*file != NULL);
 }
 
 
 char*
-eog_uri_converter_preview (const char *format_str, EogImage *img, GdkPixbufFormat *format, 
+eog_uri_converter_preview (const char *format_str, EogImage *img, GdkPixbufFormat *format,
 			   gulong counter, guint n_images,
 			   gboolean convert_spaces, gunichar space_char)
 {
@@ -853,7 +851,7 @@ eog_uri_converter_preview (const char *format_str, EogImage *img, GdkPixbufForma
 	const char *s;
 	gunichar c;
 	char *filename;
-	gboolean token_next; 
+	gboolean token_next;
 
 	g_return_val_if_fail (format_str != NULL, NULL);
 	g_return_val_if_fail (EOG_IS_IMAGE (img), NULL);
@@ -863,7 +861,7 @@ eog_uri_converter_preview (const char *format_str, EogImage *img, GdkPixbufForma
 	n_digits = ceil (MIN (log10 (G_MAXULONG), MAX (log10 (counter), log10 (n_images))));
 
 	str = g_string_new ("");
-	
+
 	if (!g_utf8_validate (format_str, -1, NULL))
 	    return NULL;
 
@@ -934,23 +932,23 @@ eog_uri_converter_preview (const char *format_str, EogImage *img, GdkPixbufForma
 			/* use same file type/suffix */
 			char *name;
 			char *old_suffix;
-			GnomeVFSURI *img_uri;
-			
-			img_uri = eog_image_get_uri (img);
-			split_filename (img_uri, &name, &old_suffix);
+			GFile *img_file;
+
+			img_file = eog_image_get_file (img);
+			split_filename (img_file, &name, &old_suffix);
 
 			g_assert (old_suffix != NULL);
-			
+
 			g_string_append_unichar (repl_str, '.');
 			g_string_append (repl_str, old_suffix);
 
 			g_free (old_suffix);
 			g_free (name);
-			gnome_vfs_uri_unref (img_uri);
+			g_object_unref (img_file);
 		}
 		else {
 			char *suffix = eog_pixbuf_get_common_suffix (format);
-			
+
 			g_string_append_unichar (repl_str, '.');
 			g_string_append (repl_str, suffix);
 
@@ -978,34 +976,34 @@ gboolean
 eog_uri_converter_check (EogURIConverter *converter, GList *img_list, GError **error)
 {
 	GList *it;
-	GList *uri_list = NULL;
-	gboolean all_different = TRUE; 
+	GList *file_list = NULL;
+	gboolean all_different = TRUE;
 
 	g_return_val_if_fail (EOG_IS_URI_CONVERTER (converter), FALSE);
 
 	/* convert all image uris */
 	for (it = img_list; it != NULL; it = it->next) {
 		gboolean result;
-		GnomeVFSURI *uri;
+		GFile *file;
 		GError *conv_error = NULL;
 
-		result = eog_uri_converter_do (converter, EOG_IMAGE (it->data), 
-					       &uri, NULL, &conv_error);
+		result = eog_uri_converter_do (converter, EOG_IMAGE (it->data),
+					       &file, NULL, &conv_error);
 
 		if (result) {
-			uri_list = g_list_prepend (uri_list, uri);
+			file_list = g_list_prepend (file_list, file);
 		}
 	}
 
 	/* check for all different uris */
-	for (it = uri_list; it != NULL && all_different; it = it->next) {
-		GList *p; 
-		GnomeVFSURI *uri;
+	for (it = file_list; it != NULL && all_different; it = it->next) {
+		GList *p;
+		GFile *file;
+
+		file = (GFile*) it->data;
 
-		uri = (GnomeVFSURI*) it->data;
-		
 		for (p = it->next; p != NULL && all_different; p = p->next) {
-			all_different = !gnome_vfs_uri_equal (uri, (GnomeVFSURI*) p->data);
+			all_different = !g_file_equal (file, (GFile*) p->data);
 		}
 	}
 
