@@ -1,4 +1,4 @@
-/* Eye Of Gnome - General Utilities 
+/* Eye Of Gnome - General Utilities
  *
  * Copyright (C) 2006 The Free Software Foundation
  *
@@ -42,16 +42,20 @@
 #include <gtk/gtk.h>
 #include <gio/gio.h>
 #include <glib/gi18n.h>
-#include <libgnome/gnome-help.h>
 #include <libgnome/gnome-init.h>
-#include <libgnome/gnome-desktop-item.h>
 
-void 
+void
 eog_util_show_help (const gchar *section, GtkWindow *parent)
 {
 	GError *error = NULL;
+	char *uri;
 
-	gnome_help_display ("eog.xml", section, &error);
+	if (section)
+		uri = g_strdup_printf ("ghelp:eog?%s", section);
+	else
+		uri = "ghelp:eog";
+
+	gtk_show_uri (NULL, uri, gtk_get_current_event_time (), &error);
 
 	if (error) {
 		GtkWidget *dialog;
@@ -136,7 +140,7 @@ eog_util_parse_uri_string_list_to_file_list (const gchar *uri_list)
 		file_list = g_slist_append (file_list, g_file_new_for_uri (uri));
 		g_free (uri);
 	}
-	
+
 	return file_list;
 }
 
@@ -150,8 +154,8 @@ eog_util_string_list_to_file_list (GSList *string_list)
 		char *uri_str;
 
 		uri_str = (gchar *) it->data;
-		
-		file_list = g_slist_prepend (file_list, 
+
+		file_list = g_slist_prepend (file_list,
 					     g_file_new_for_uri (uri_str));
 	}
 
@@ -166,10 +170,10 @@ eog_util_strings_to_file_list (gchar **strings)
  	GSList *file_list = NULL;
 
 	for (i = 0; strings[i]; i++) {
- 		file_list = g_slist_prepend (file_list, 
+ 		file_list = g_slist_prepend (file_list,
 					      g_file_new_for_uri (strings[i]));
  	}
- 
+
  	return g_slist_reverse (file_list);
 }
 #endif
@@ -187,10 +191,10 @@ eog_util_string_array_to_list (const gchar **files, gboolean create_uri)
 
 		if (create_uri) {
 			GFile *file;
-			
+
 			file = g_file_new_for_commandline_arg (files[i]);
 			str = g_file_get_uri (file);
-			
+
 			g_object_unref (file);
 		} else {
 			str = g_strdup (files[i]);
@@ -220,85 +224,17 @@ eog_util_string_array_make_absolute (gchar **files)
 
 	/* Ensure new list is NULL-terminated */
 	abs_files = g_new0 (gchar *, size+1);
-	
+
 	for (i = 0; i < size; i++) {
 		file = g_file_new_for_commandline_arg (files[i]);
 		abs_files[i] = g_file_get_uri (file);
 
 		g_object_unref (file);
 	}
-	
+
 	return abs_files;
 }
 
-static int
-launch_desktop_item (const char *desktop_file,
-                     guint32 user_time,
-                     GError **error)
-{
-	GnomeDesktopItem *item = NULL;
-	GList *uris = NULL;
-	int ret = -1;
-	
-	item = gnome_desktop_item_new_from_file (desktop_file, 0, NULL);
-
-	if (item == NULL) return FALSE;
-	
-	gnome_desktop_item_set_launch_time (item, user_time);
-
-	ret = gnome_desktop_item_launch (item, uris, 0, error);
-	
-	g_list_foreach (uris, (GFunc) g_free, NULL);
-	g_list_free (uris);
-	gnome_desktop_item_unref (item);
-	
-	return ret;
-}
-
-gboolean
-eog_util_launch_desktop_file (const gchar *filename,
-                              guint32      user_time)
-{
-	GError *error = NULL;
-	const char * const *dirs;
-	char *path = NULL;
-	int i, ret = -1;
-	
-	dirs = g_get_system_data_dirs ();
-
-	if (dirs == NULL) return FALSE;
-	
-	for (i = 0; dirs[i] != NULL; i++) {
-	        path = g_build_filename (dirs[i], 
-					 "applications", 
-					 filename, 
-					 NULL);
-
-	        if (g_file_test (path, G_FILE_TEST_IS_REGULAR)) break;
-	
-	        g_free (path);
-		path = NULL;
-	}
-	
-	if (path != NULL) {
-	        ret = launch_desktop_item (path, user_time, &error);
-	
-	        if (ret == -1 || error != NULL) {
-	                g_warning ("Cannot launch desktop item '%s': %s\n",
-	                           path, 
-				   error ? error->message : "unknown error");
-
-	                g_clear_error (&error);
-	        }
-	
-	        g_free (path);
-	}
-	
-	return ret >= 0;
-}
-
-/* Above code courtesy of Evince hackers */
-
 static gchar *dot_dir = NULL;
 
 static gboolean
@@ -306,13 +242,13 @@ ensure_dir_exists (const char *dir)
 {
 	if (g_file_test (dir, G_FILE_TEST_IS_DIR))
 		return TRUE;
-	
+
 	if (g_mkdir (dir, 488) == 0)
 		return TRUE;
 
 	if (errno == EEXIST)
 		return g_file_test (dir, G_FILE_TEST_IS_DIR);
-	
+
 	g_warning ("Failed to create directory %s: %s", dir, strerror (errno));
 	return FALSE;
 }
@@ -322,11 +258,11 @@ eog_util_dot_dir (void)
 {
 	if (dot_dir == NULL) {
 		gboolean exists;
-		
+
 		dot_dir = g_build_filename (gnome_user_dir_get (),
 					    "eog",
 					    NULL);
-		
+
 		exists = ensure_dir_exists (dot_dir);
 
 		if (G_UNLIKELY (!exists)) {
@@ -343,3 +279,46 @@ eog_util_dot_dir (void)
 
 	return dot_dir;
 }
+
+/* Based on eel_filename_strip_extension() */
+
+/**
+ * eog_util_filename_get_extension:
+ * @filename: a filename
+ *
+ * Returns a reasonably good guess of the file extension of @filename.
+ *
+ * Returns: a newly allocated string with the file extension of @filename.
+ **/
+char *
+eog_util_filename_get_extension (const char * filename)
+{
+	char *begin, *begin2;
+
+	if (filename == NULL) {
+		return NULL;
+	}
+
+	begin = strrchr (filename, '.');
+
+	if (begin && begin != filename) {
+		if (strcmp (begin, ".gz") == 0 ||
+		    strcmp (begin, ".bz2") == 0 ||
+		    strcmp (begin, ".sit") == 0 ||
+		    strcmp (begin, ".Z") == 0) {
+			begin2 = begin - 1;
+			while (begin2 > filename &&
+			       *begin2 != '.') {
+				begin2--;
+			}
+			if (begin2 != filename) {
+				begin = begin2;
+			}
+		}
+		begin ++;
+	} else {
+		return NULL;
+	}
+
+	return g_strdup (begin);
+}
